@@ -19,7 +19,7 @@ Romanian_Libreoffice
    <de>Rumänisches Meta-Paket für LibreOffice</de>
    <el>LibreOffice στα Ρουμανικά</el>
    <en>Romanian Language Meta-Package for LibreOffice</en>
-   <es>Romanian Language Meta-Package for LibreOffice</es>
+   <es>Meta-Paquete de Idioma Rumano para LibreOffice</es>
    <et>Romanian Language Meta-Package for LibreOffice</et>
    <eu>Romanian Language Meta-Package for LibreOffice</eu>
    <fa>Romanian Language Meta-Package for LibreOffice</fa>
@@ -40,7 +40,7 @@ Romanian_Libreoffice
    <mk>Romanian Language Meta-Package for LibreOffice</mk>
    <nb>Romanian Language Meta-Package for LibreOffice</nb>
    <nl>Roemeense Taal Meta-Pakket voor LibreOffice</nl>
-   <pl>Romanian Language Meta-Package for LibreOffice</pl>
+   <pl>Rumuński metapakiet językowy dla LibreOffice</pl>
    <pt_BR>Romeno Meta-Pacote de Idioma para LibreOffice</pt_BR>
    <pt>Romeno Meta-Pacote de Idioma para LibreOffice</pt>
    <ro>Romanian Language Meta-Package for LibreOffice</ro>
