@@ -19,7 +19,7 @@ SuperTuxKart
    <de>Mario-Kart-Rennen</de>
    <el>Mario kart style racing</el>
    <en>Mario kart style racing</en>
-   <es>juego de carreras estilo Mario kart</es>
+   <es>Juego de carreras estilo Mario kart</es>
    <et>Mario kart style racing</et>
    <eu>Mario kart style racing</eu>
    <fa>Mario kart style racing</fa>
@@ -40,7 +40,7 @@ SuperTuxKart
    <mk>Mario kart style racing</mk>
    <nb>Mario kart style racing</nb>
    <nl>Mario kart stijl racen</nl>
-   <pl>Mario kart style racing</pl>
+   <pl>wyścigi w stylu Mario Kart</pl>
    <pt_BR>Mario kart style racing</pt_BR>
    <pt>Mario kart style racing</pt>
    <ro>Mario kart style racing</ro>
